# Generated by @typespec-fastapi/emitter
# Do not edit this file manually — regenerate with: tsp compile .
"""Repository layer for file-based data access."""
from __future__ import annotations

from .repository import Repository
from .stub_repository import StubRepository

__all__ = ["Repository", "StubRepository"]
