# Generated by @typespec-fastapi/emitter
# Do not edit this file manually — regenerate with: tsp compile .
"""FastAPI routers generated from TypeSpec operations."""
from __future__ import annotations

from .embeddings import router as embeddings_router
from .search import router as search_router
from .sessions import router as sessions_router

__all__ = [
    "embeddings_router",
    "search_router",
    "sessions_router",
]
